@@ -1,7 +1,7 @@
 // qjackctlAlsaConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -31,12 +31,9 @@
 //
 
 // Constructor.
-qjackctlAlsaPort::qjackctlAlsaPort (
-	qjackctlAlsaClient *pClient, int iAlsaPort )
+qjackctlAlsaPort::qjackctlAlsaPort ( qjackctlAlsaClient *pClient )
 	: qjackctlPortItem(pClient)
 {
-	m_iAlsaPort = iAlsaPort;
-
 	qjackctlAlsaConnect *pAlsaConnect
 		= static_cast<qjackctlAlsaConnect *> (
 			((pClient->clientList())->listView())->binding());
@@ -66,7 +63,7 @@ int qjackctlAlsaPort::alsaClient (void) const
 
 int qjackctlAlsaPort::alsaPort (void) const
 {
-	return m_iAlsaPort;
+	return portName().section(':', 0, 0).toInt();
 }
 
 
@@ -75,12 +72,9 @@ int qjackctlAlsaPort::alsaPort (void) const
 //
 
 // Constructor.
-qjackctlAlsaClient::qjackctlAlsaClient (
-	qjackctlAlsaClientList *pClientList, int iAlsaClient )
+qjackctlAlsaClient::qjackctlAlsaClient ( qjackctlAlsaClientList *pClientList )
 	: qjackctlClientItem(pClientList)
 {
-	m_iAlsaClient = iAlsaClient;
-
 	qjackctlAlsaConnect *pAlsaConnect
 		= static_cast<qjackctlAlsaConnect *> (
 			(pClientList->listView())->binding());
@@ -105,7 +99,7 @@ qjackctlAlsaClient::~qjackctlAlsaClient (void)
 // Jack client accessor.
 int qjackctlAlsaClient::alsaClient (void) const
 {
-	return m_iAlsaClient;
+	return clientName().section(':', 0, 0).toInt();
 }
 
 
@@ -120,7 +114,7 @@ qjackctlAlsaPort *qjackctlAlsaClient::findPort ( int iAlsaPort )
 			return pPort;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 
@@ -152,7 +146,7 @@ qjackctlAlsaClient *qjackctlAlsaClientList::findClient ( int iAlsaClient )
 			return pClient;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 
@@ -161,8 +155,8 @@ qjackctlAlsaPort *qjackctlAlsaClientList::findClientPort ( int iAlsaClient,
 	int iAlsaPort )
 {
 	qjackctlAlsaClient *pClient = findClient(iAlsaClient);
-	if (pClient == NULL)
-		return NULL;
+	if (pClient == nullptr)
+		return nullptr;
 
 	return pClient->findPort(iAlsaPort);
 }
@@ -172,11 +166,11 @@ qjackctlAlsaPort *qjackctlAlsaClientList::findClientPort ( int iAlsaClient,
 int qjackctlAlsaClientList::updateClientPorts (void)
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return 0;
 
 	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
-	if (pAlsaSeq == NULL)
+	if (pAlsaSeq == nullptr)
 		return 0;
 
 	int iDirtyCount = 0;
@@ -216,7 +210,7 @@ int qjackctlAlsaClientList::updateClientPorts (void)
 					qjackctlAlsaPort *pPort = 0;
 					const int iAlsaPort = snd_seq_port_info_get_port(pPortInfo);
 					if (pClient == 0) {
-						pClient = new qjackctlAlsaClient(this, iAlsaClient);
+						pClient = new qjackctlAlsaClient(this);
 						pClient->setClientName(sClientName);
 						iDirtyCount++;
 					} else {
@@ -231,7 +225,7 @@ int qjackctlAlsaClientList::updateClientPorts (void)
 						sPortName += QString::fromUtf8(
 							snd_seq_port_info_get_name(pPortInfo));
 						if (pPort == 0) {
-							pPort = new qjackctlAlsaPort(pClient, iAlsaPort);
+							pPort = new qjackctlAlsaPort(pClient);
 							pPort->setPortName(sPortName);
 							iDirtyCount++;
 						} else if (sPortName != pPort->portName()) {
@@ -298,7 +292,7 @@ void qjackctlAlsaConnect::deleteIconPixmaps (void)
 	for (int i = 0; i < QJACKCTL_ALSA_PIXMAPS; i++) {
 		if (m_apPixmaps[i])
 			delete m_apPixmaps[i];
-		m_apPixmaps[i] = NULL;
+		m_apPixmaps[i] = nullptr;
 	}
 }
 
@@ -310,11 +304,11 @@ bool qjackctlAlsaConnect::connectPorts (
 #ifdef CONFIG_ALSA_SEQ
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return false;
 
 	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
-	if (pAlsaSeq == NULL)
+	if (pAlsaSeq == nullptr)
 		return false;
 
 	qjackctlAlsaPort *pOAlsa = static_cast<qjackctlAlsaPort *> (pOPort);
@@ -350,11 +344,11 @@ bool qjackctlAlsaConnect::disconnectPorts (
 #ifdef CONFIG_ALSA_SEQ
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return false;
 
 	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
-	if (pAlsaSeq == NULL)
+	if (pAlsaSeq == nullptr)
 		return false;
 
 	qjackctlAlsaPort *pOAlsa = static_cast<qjackctlAlsaPort *> (pOPort);
@@ -389,11 +383,11 @@ void qjackctlAlsaConnect::updateConnections (void)
 #ifdef CONFIG_ALSA_SEQ
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
-	if (pAlsaSeq == NULL)
+	if (pAlsaSeq == nullptr)
 		return;
 
 	snd_seq_query_subscribe_t *pAlsaSubs;
