@@ -1,7 +1,7 @@
 // qjackctlConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -36,7 +36,7 @@
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
 
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QMimeData>
 #include <QDrag>
 #endif
@@ -99,12 +99,12 @@ void qjackctlPortItem::setPortNameAlias ( const QString& sPortNameAlias )
 	// Check aliasing...
 	qjackctlClientListView *pClientListView
 		= (m_pClient->clientList())->listView();
-	qjackctlConnectAlias *pAliases
-		= pClientListView->aliases();
-	if (pAliases) {
+	qjackctlAliasList *pAliasList
+		= pClientListView->aliasList();
+	if (pAliasList) {
 		const QString& sClientName = m_pClient->clientName();
-		pAliases->setPortAlias(sClientName, m_sPortName, sPortNameAlias);
-		pClientListView->setDirty(true);
+		pAliasList->setPortAlias(sClientName, m_sPortName, sPortNameAlias);
+		pClientListView->emitAliasesChanged();
 	}
 }
 
@@ -116,11 +116,11 @@ QString qjackctlPortItem::portNameAlias ( bool *pbRenameEnabled ) const
 	// Check aliasing...
 	qjackctlClientListView *pClientListView
 		= (m_pClient->clientList())->listView();
-	qjackctlConnectAlias *pAliases
-		= pClientListView->aliases();
-	if (pAliases) {
+	qjackctlAliasList *pAliasList
+		= pClientListView->aliasList();
+	if (pAliasList) {
 		const QString& sClientName = m_pClient->clientName();
-		sPortNameAlias = pAliases->portAlias(sClientName, m_sPortName);
+		sPortNameAlias = pAliasList->portAlias(sClientName, m_sPortName);
 		bRenameEnabled = pClientListView->isRenameEnabled();
 	}
 
@@ -228,7 +228,7 @@ qjackctlPortItem *qjackctlPortItem::findConnect ( const QString& sClientPortName
 			return pPort;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 qjackctlPortItem *qjackctlPortItem::findConnectPtr ( qjackctlPortItem *pPortPtr )
@@ -240,7 +240,7 @@ qjackctlPortItem *qjackctlPortItem::findConnectPtr ( qjackctlPortItem *pPortPtr
 			return pPort;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 
@@ -268,11 +268,11 @@ void qjackctlPortItem::setHilite ( bool bHilite )
 
 	// Set the new color.
 	QTreeWidget *pTreeWidget = QTreeWidgetItem::treeWidget();
-	if (pTreeWidget == NULL)
+	if (pTreeWidget == nullptr)
 		return;
 
 	const QPalette& pal = pTreeWidget->palette();
-	QTreeWidgetItem::setTextColor(0, m_bHilite
+	QTreeWidgetItem::setForeground(0, m_bHilite
 		? (pal.base().color().value() < 0x7f ? Qt::cyan : Qt::blue)
 		: pal.text().color());
 }
@@ -324,7 +324,7 @@ qjackctlPortItem *qjackctlClientItem::findPort (const QString& sPortName)
 			return pPort;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 
@@ -361,11 +361,11 @@ void qjackctlClientItem::setClientNameAlias ( const QString& sClientNameAlias )
 {
 	qjackctlClientListView *pClientListView
 		= m_pClientList->listView();
-	qjackctlConnectAlias *pAliases
-		= pClientListView->aliases();
-	if (pAliases) {
-		pAliases->setClientAlias(m_sClientName, sClientNameAlias);
-		pClientListView->setDirty(true);
+	qjackctlAliasList *pAliasList
+		= pClientListView->aliasList();
+	if (pAliasList) {
+		pAliasList->setClientAlias(m_sClientName, sClientNameAlias);
+		pClientListView->emitAliasesChanged();
 	}
 }
 
@@ -377,10 +377,10 @@ QString qjackctlClientItem::clientNameAlias ( bool *pbRenameEnabled ) const
 	// Check aliasing...
 	qjackctlClientListView *pClientListView
 		= m_pClientList->listView();
-	qjackctlConnectAlias *pAliases
-		= pClientListView->aliases();
-	if (pAliases) {
-		sClientNameAlias = pAliases->clientAlias(m_sClientName);
+	qjackctlAliasList *pAliasList
+		= pClientListView->aliasList();
+	if (pAliasList) {
+		sClientNameAlias = pAliasList->clientAlias(m_sClientName);
 		bRenameEnabled = pClientListView->isRenameEnabled();
 	}
 
@@ -481,11 +481,11 @@ void qjackctlClientItem::setHilite ( bool bHilite )
 
 	// Set the new color.
 	QTreeWidget *pTreeWidget = QTreeWidgetItem::treeWidget();
-	if (pTreeWidget == NULL)
+	if (pTreeWidget == nullptr)
 		return;
 
 	const QPalette& pal = pTreeWidget->palette();
-	QTreeWidgetItem::setTextColor(0, m_iHilite > 0
+	QTreeWidgetItem::setForeground(0, m_iHilite > 0
 		? (pal.base().color().value() < 0x7f ? Qt::darkCyan : Qt::darkBlue)
 		: pal.text().color());
 }
@@ -555,7 +555,7 @@ qjackctlClientItem *qjackctlClientList::findClient (
 			return pClient;
 	}
 
-	return NULL;
+	return nullptr;
 }
 
 // Client:port finder.
@@ -678,52 +678,52 @@ void qjackctlClientList::hiliteClientPorts (void)
 
 // Natural decimal sorting comparator.
 bool qjackctlClientList::lessThan (
-	const QTreeWidgetItem& i1, const QTreeWidgetItem& i2 )
+	const QTreeWidgetItem& item1, const QTreeWidgetItem& item2 )
 {
-	const QString& s1 = i1.text(0);
-	const QString& s2 = i2.text(0);
+	const QString& s1 = item1.text(0);
+	const QString& s2 = item2.text(0);
 
-	const int cch1 = s1.length();
-	const int cch2 = s2.length();
+	const int n1 = s1.length();
+	const int n2 = s2.length();
 
-	int ich1, ich2;
+	int i1, i2;
 
-	for (ich1 = ich2 = 0; ich1 < cch1 && ich2 < cch2; ich1++, ich2++) {
+	for (i1 = i2 = 0; i1 < n1 && i2 < n2; ++i1, ++i2) {
 
-		// Skip (white)spaces...
-		while (s1.at(ich1).isSpace())
-			ich1++;
-		while (s2.at(ich2).isSpace())
-			ich2++;
+		// skip (white)spaces...
+		while (s1.at(i1).isSpace())
+			++i1;
+		while (s2.at(i2).isSpace())
+			++i2;
 
 		// Normalize (to uppercase) the next characters...
-		QChar ch1 = s1.at(ich1).toUpper();
-		QChar ch2 = s2.at(ich2).toUpper();
+		QChar c1 = s1.at(i1).toUpper();
+		QChar c2 = s2.at(i2).toUpper();
 
-		if (ch1.isDigit() && ch2.isDigit()) {
+		if (c1.isDigit() && c2.isDigit()) {
 			// Find the whole length numbers...
-			const int iDigits1 = ich1++;
-			while (ich1 < cch1 && s1.at(ich1).isDigit())
-				ich1++;
-			const int iDigits2 = ich2++;
-			while (ich2 < cch2 && s2.at(ich2).isDigit())
-				ich2++;
+			int j1 = i1++;
+			while (i1 < n1 && s1.at(i1).isDigit())
+				++i1;
+			int j2 = i2++;
+			while (i2 < n2 && s2.at(i2).isDigit())
+				++i2;
 			// Compare as natural decimal-numbers...
-			const int n1 = s1.mid(iDigits1, ich1 - iDigits1).toInt();
-			const int n2 = s2.mid(iDigits2, ich2 - iDigits2).toInt();
-			if (n1 != n2)
-				return (n1 < n2);
+			j1 = s1.mid(j1, i1 - j1).toInt();
+			j2 = s2.mid(j2, i2 - j2).toInt();
+			if (j1 != j2)
+				return (j1 < j2);
 			// Never go out of bounds...
-			if (ich1 >= cch1 || ich1 >= cch2)
+			if (i1 >= n1 || i2 >= n2)
 				break;
 			// Go on with this next char...
-			ch1 = s1.at(ich1).toUpper();
-			ch2 = s2.at(ich2).toUpper();
+			c1 = s1.at(i1).toUpper();
+			c2 = s2.at(i2).toUpper();
 		}
 
 		// Compare this char...
-		if (ch1 != ch2)
-			return (ch1 < ch2);
+		if (c1 != c2)
+			return (c1 < c2);
 	}
 
 	// Probable exact match.
@@ -754,16 +754,16 @@ qjackctlClientListView::qjackctlClientListView (
 	m_pAutoOpenTimer   = 0;
 	m_iAutoOpenTimeout = 0;
 
-	m_pDragItem = NULL;
-	m_pDragItem = NULL;
+	m_pDragItem = nullptr;
+	m_pDragItem = nullptr;
 
-	m_pAliases = NULL;
+	m_pAliasList = nullptr;
 	m_bRenameEnabled = false;
 
 	QHeaderView *pHeader = QTreeWidget::header();
 	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(120);
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 //	pHeader->setSectionResizeMode(QHeaderView::Custom);
 	pHeader->setSectionsMovable(false);
 	pHeader->setSectionsClickable(true);
@@ -781,7 +781,7 @@ qjackctlClientListView::qjackctlClientListView (
 	QTreeWidget::setAcceptDrops(true);
 	QTreeWidget::setDropIndicatorShown(true);
 	QTreeWidget::setAutoScroll(true);
-	QTreeWidget::setSelectionMode(QAbstractItemView::SingleSelection);
+	QTreeWidget::setSelectionMode(QAbstractItemView::ExtendedSelection);
 	QTreeWidget::setSizePolicy(
 		QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
 	QTreeWidget::setSortingEnabled(true);
@@ -828,7 +828,7 @@ void qjackctlClientListView::setAutoOpenTimeout ( int iAutoOpenTimeout )
 
 	if (m_pAutoOpenTimer)
 		delete m_pAutoOpenTimer;
-	m_pAutoOpenTimer = NULL;
+	m_pAutoOpenTimer = nullptr;
 
 	if (m_iAutoOpenTimeout > 0) {
 		m_pAutoOpenTimer = new QTimer(this);
@@ -847,10 +847,10 @@ int qjackctlClientListView::autoOpenTimeout (void) const
 
 
 // Aliasing support methods.
-void qjackctlClientListView::setAliases (
-	qjackctlConnectAlias *pAliases, bool bRenameEnabled )
+void qjackctlClientListView::setAliasList (
+	qjackctlAliasList *pAliasList, bool bRenameEnabled )
 {
-	m_pAliases = pAliases;
+	m_pAliasList = pAliasList;
 	m_bRenameEnabled = bRenameEnabled;
 
 	// For each client item, if any.
@@ -861,7 +861,7 @@ void qjackctlClientListView::setAliases (
 			continue;
 		qjackctlClientItem *pClientItem
 			= static_cast<qjackctlClientItem *> (pItem);
-		if (pClientItem == NULL)
+		if (pClientItem == nullptr)
 			continue;
 		pClientItem->updateClientName();
 		// For each port item...
@@ -872,16 +872,16 @@ void qjackctlClientListView::setAliases (
 				continue;
 			qjackctlPortItem *pPortItem
 				= static_cast<qjackctlPortItem *> (pChildItem);
-			if (pPortItem == NULL)
+			if (pPortItem == nullptr)
 				continue;
 			pPortItem->updatePortName();
 		}
 	}
 }
 
-qjackctlConnectAlias *qjackctlClientListView::aliases (void) const
+qjackctlAliasList *qjackctlClientListView::aliasList (void) const
 {
-	return m_pAliases;
+	return m_pAliasList;
 }
 
 bool qjackctlClientListView::isRenameEnabled (void) const
@@ -902,11 +902,11 @@ void qjackctlClientListView::startRenameSlot (void)
 // In-place aliasing slot.
 void qjackctlClientListView::renamedSlot (void)
 {
-	if (m_pAliases == NULL)
+	if (m_pAliasList == nullptr)
 		return;
 
 	QTreeWidgetItem *pItem = QTreeWidget::currentItem();
-	if (pItem == NULL)
+	if (pItem == nullptr)
 		return;
 
 	const QString& sText = pItem->text(0);
@@ -989,11 +989,11 @@ QTreeWidgetItem *qjackctlClientListView::dragDropItem ( const QPoint& pos )
 				m_pAutoOpenTimer->start(m_iAutoOpenTimeout);
 			qjackctlConnect *pConnect = m_pConnectView->binding();
 			if ((pItem->flags() & Qt::ItemIsDropEnabled) == 0
-				|| pConnect == NULL || !pConnect->canConnectSelected())
-				pItem = NULL;
+				|| pConnect == nullptr || !pConnect->canConnectSelected())
+				pItem = nullptr;
 		}
 	} else {
-		m_pDropItem = NULL;
+		m_pDropItem = nullptr;
 		if (m_pAutoOpenTimer)
 			m_pAutoOpenTimer->stop();
 	}
@@ -1074,9 +1074,9 @@ void qjackctlClientListView::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 		pDrag->setMimeData(pMimeData);
 		pDrag->setPixmap(m_pDragItem->icon(0).pixmap(16));
 		pDrag->setHotSpot(QPoint(-4, -12));
-		pDrag->start(Qt::LinkAction);
+		pDrag->exec(Qt::LinkAction);
 		// We've dragged and maybe dropped it by now...
-		m_pDragItem = NULL;
+		m_pDragItem = nullptr;
 	}
 }
 
@@ -1121,15 +1121,10 @@ void qjackctlClientListView::contextMenuEvent ( QContextMenuEvent *pContextMenuE
 
 
 
-// Dirty flag methods.
-void qjackctlClientListView::setDirty ( bool bDirty )
+// Dirty aliases notification.
+void qjackctlClientListView::emitAliasesChanged (void)
 {
-	m_pConnectView->setDirty(bDirty);
-}
-
-bool qjackctlClientListView::isDirty (void) const
-{
-	return m_pConnectView->isDirty();
+	m_pConnectView->emitAliasesChanged();
 }
 
 
@@ -1162,7 +1157,7 @@ int qjackctlConnectorView::itemY ( QTreeWidgetItem *pItem ) const
 	QRect rect;
 	QTreeWidget *pList = pItem->treeWidget();
 	QTreeWidgetItem *pParent = pItem->parent();
-	qjackctlClientItem *pClientItem = NULL;
+	qjackctlClientItem *pClientItem = nullptr;
 	if (pParent && pParent->type() == QJACKCTL_CLIENTITEM)
 		pClientItem = static_cast<qjackctlClientItem *> (pParent);
 	if (pClientItem && !pClientItem->isOpen()) {
@@ -1189,21 +1184,17 @@ void qjackctlConnectorView::drawConnectionLine ( QPainter *pPainter,
 	if (y1 > h1)
 		pPainter->drawLine(x1, y1, x1 + 4, y1);
 
-	// How do we'll draw it?
-	if (m_pConnectView->isBezierLines()) {
-		// Setup control points
-		QPolygon spline(4);
-		const int cp = int(float(x2 - x1 - 8) * 0.4f);
-		spline.putPoints(0, 4,
-			x1 + 4, y1, x1 + 4 + cp, y1, 
-			x2 - 4 - cp, y2, x2 - 4, y2);
-		// The connection line, it self.
-		QPainterPath path;
-		path.moveTo(spline.at(0));
-		path.cubicTo(spline.at(1), spline.at(2), spline.at(3));
-		pPainter->strokePath(path, pen);
-	}
-	else pPainter->drawLine(x1 + 4, y1, x2 - 4, y2);
+	// Setup control points
+	QPolygon spline(4);
+	const int cp = int(float(x2 - x1 - 8) * 0.4f);
+	spline.putPoints(0, 4,
+		x1 + 4, y1, x1 + 4 + cp, y1,
+		x2 - 4 - cp, y2, x2 - 4, y2);
+	// The connection line, it self.
+	QPainterPath path;
+	path.moveTo(spline.at(0));
+	path.cubicTo(spline.at(1), spline.at(2), spline.at(3));
+	pPainter->strokePath(path, pen);
 
 	// Invisible input ports don't get a connecting dot.
 	if (y2 > h2)
@@ -1214,10 +1205,10 @@ void qjackctlConnectorView::drawConnectionLine ( QPainter *pPainter,
 // Draw visible port connection relation arrows.
 void qjackctlConnectorView::paintEvent ( QPaintEvent * )
 {
-	if (m_pConnectView == NULL)
+	if (m_pConnectView == nullptr)
 		return;
-	if (m_pConnectView->OListView() == NULL ||
-		m_pConnectView->IListView() == NULL)
+	if (m_pConnectView->OListView() == nullptr ||
+		m_pConnectView->IListView() == nullptr)
 		return;
 
 	qjackctlClientListView *pOListView = m_pConnectView->OListView();
@@ -1254,7 +1245,7 @@ void qjackctlConnectorView::paintEvent ( QPaintEvent * )
 			continue;
 		qjackctlClientItem *pOClient
 			= static_cast<qjackctlClientItem *> (pItem);
-		if (pOClient == NULL)
+		if (pOClient == nullptr)
 			continue;
 		// Set new connector color.
 		++i;
@@ -1339,10 +1330,9 @@ qjackctlConnectView::qjackctlConnectView ( QWidget *pParent )
 	m_pConnectorView = new qjackctlConnectorView(this);
 	m_pIListView     = new qjackctlClientListView(this, false);
 
-	m_pConnect = NULL;
+	m_pConnect = nullptr;
 
-	m_bBezierLines = false;
-	m_iIconSize    = 0;
+	m_iIconSize = 0;
 
 	QSplitter::setHandleWidth(2);
 
@@ -1392,7 +1382,7 @@ qjackctlClientList *qjackctlConnectView::OClientList (void) const
 	if (m_pConnect)
 		return m_pConnect->OClientList();
 	else
-		return NULL;
+		return nullptr;
 }
 
 qjackctlClientList *qjackctlConnectView::IClientList (void) const
@@ -1400,19 +1390,7 @@ qjackctlClientList *qjackctlConnectView::IClientList (void) const
 	if (m_pConnect)
 		return m_pConnect->OClientList();
 	else
-		return NULL;
-}
-
-
-// Connector line style accessors.
-void qjackctlConnectView::setBezierLines ( bool bBezierLines )
-{
-	m_bBezierLines = bBezierLines;
-}
-
-bool qjackctlConnectView::isBezierLines (void) const
-{
-	return m_bBezierLines;
+		return nullptr;
 }
 
 
@@ -1444,18 +1422,10 @@ int qjackctlConnectView::iconSize (void) const
 }
 
 
-// Dirty flag methods.
-void qjackctlConnectView::setDirty ( bool bDirty )
+// Dirty aliases notification.
+void qjackctlConnectView::emitAliasesChanged (void)
 {
-	m_bDirty = bDirty;
-
-	if (bDirty)
-		emit contentsChanged();
-}
-
-bool qjackctlConnectView::isDirty (void) const
-{
-	return m_bDirty;
+	emit aliasesChanged();
 }
 
 
@@ -1468,8 +1438,8 @@ qjackctlConnect::qjackctlConnect ( qjackctlConnectView *pConnectView )
 {
 	m_pConnectView = pConnectView;
 
-	m_pOClientList = NULL;
-	m_pIClientList = NULL;
+	m_pOClientList = nullptr;
+	m_pIClientList = nullptr;
 
 	m_iMutex = 0;
 
@@ -1482,15 +1452,15 @@ qjackctlConnect::~qjackctlConnect (void)
 	// Force end of works here.
 	m_iMutex++;
 
-	m_pConnectView->setBinding(NULL);
+	m_pConnectView->setBinding(nullptr);
 
 	if (m_pOClientList)
 		delete m_pOClientList;
 	if (m_pIClientList)
 		delete m_pIClientList;
 
-	m_pOClientList = NULL;
-	m_pIClientList = NULL;
+	m_pOClientList = nullptr;
+	m_pIClientList = nullptr;
 
 	m_pConnectView->connectorView()->update();
 }
@@ -1517,7 +1487,7 @@ void qjackctlConnect::setIClientList ( qjackctlClientList *pIClientList )
 bool qjackctlConnect::connectPortsEx (
 	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
-	if (pOPort->findConnectPtr(pIPort) != NULL)
+	if (pOPort->findConnectPtr(pIPort) != nullptr)
 		return false;
 	
 	emit connecting(pOPort, pIPort);
@@ -1534,7 +1504,7 @@ bool qjackctlConnect::connectPortsEx (
 bool qjackctlConnect::disconnectPortsEx (
 	qjackctlPortItem *pOPort, qjackctlPortItem *pIPort )
 {
-	if (pOPort->findConnectPtr(pIPort) == NULL)
+	if (pOPort->findConnectPtr(pIPort) == nullptr)
 		return false;
 
 	emit disconnecting(pOPort, pIPort);
@@ -1569,61 +1539,75 @@ bool qjackctlConnect::canConnectSelectedEx (void)
 	m_pConnectView->connectorView()->update();
 
 	// Now with our predicate work...
-	QTreeWidgetItem *pOItem = (m_pOClientList->listView())->currentItem();
-	if (pOItem == NULL)
+	const QList<QTreeWidgetItem *> oitems
+		= (m_pOClientList->listView())->selectedItems();
+	const QList<QTreeWidgetItem *> iitems
+		= (m_pIClientList->listView())->selectedItems();
+
+	if (oitems.isEmpty() || iitems.isEmpty())
 		return false;
 
-	QTreeWidgetItem *pIItem = (m_pIClientList->listView())->currentItem();
-	if (pIItem == NULL)
-		return false;
+	QListIterator<QTreeWidgetItem *> oiter(oitems);
+	QListIterator<QTreeWidgetItem *> iiter(iitems);
 
-	if (pOItem->type() == QJACKCTL_CLIENTITEM) {
-		qjackctlClientItem *pOClient
-			= static_cast<qjackctlClientItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// Each-to-each connections...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (oport.hasNext() && iport.hasNext()) {
-				qjackctlPortItem *pOPort = oport.next();
-				qjackctlPortItem *pIPort = iport.next();
-				if (pOPort->findConnectPtr(pIPort) == NULL)
-					return true;
+	const int iNumItems
+		= qMax(oitems.count(), iitems.count());
+
+	for (int i = 0; i < iNumItems; ++i) {
+		if (!oiter.hasNext())
+			oiter.toFront();
+		if (!iiter.hasNext())
+			iiter.toFront();
+		QTreeWidgetItem *pOItem = oiter.next();
+		QTreeWidgetItem *pIItem = iiter.next();
+		if (pOItem->type() == QJACKCTL_CLIENTITEM) {
+			qjackctlClientItem *pOClient
+				= static_cast<qjackctlClientItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// Each-to-each connections...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (oport.hasNext() && iport.hasNext()) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort = iport.next();
+					if (pOPort->findConnectPtr(pIPort) == nullptr)
+						return true;
+				}
+			} else {
+				// Many(all)-to-one/many connection...
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				while (oport.hasNext()
+					&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort
+						= static_cast<qjackctlPortItem *> (pIItem);
+					if (pOPort->findConnectPtr(pIPort) == nullptr)
+						return true;
+					pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
+				}
 			}
 		} else {
-			// Many(all)-to-one/many connection...
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			while (oport.hasNext()
-				&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
-				qjackctlPortItem *pOPort = oport.next();
+			qjackctlPortItem *pOPort
+				= static_cast<qjackctlPortItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// One-to-many(all) connection...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (iport.hasNext()) {
+					qjackctlPortItem *pIPort = iport.next();
+					if (pOPort->findConnectPtr(pIPort) == nullptr)
+						return true;
+				}
+			} else {
+				// One-to-one connection...
 				qjackctlPortItem *pIPort
 					= static_cast<qjackctlPortItem *> (pIItem);
-				if (pOPort->findConnectPtr(pIPort) == NULL)
-					return true;
-				pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
+				return (pOPort->findConnectPtr(pIPort) == nullptr);
 			}
 		}
-	} else {
-		qjackctlPortItem *pOPort
-			= static_cast<qjackctlPortItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// One-to-many(all) connection...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (iport.hasNext()) {
-				qjackctlPortItem *pIPort = iport.next();
-				if (pOPort->findConnectPtr(pIPort) == NULL)
-					return true;
-			}
-		} else {
-			// One-to-one connection...
-			qjackctlPortItem *pIPort
-				= static_cast<qjackctlPortItem *> (pIItem);
-			return (pOPort->findConnectPtr(pIPort) == NULL);
-		}
 	}
 
 	return false;
@@ -1650,58 +1634,72 @@ bool qjackctlConnect::connectSelected (void)
 
 bool qjackctlConnect::connectSelectedEx (void)
 {
-	QTreeWidgetItem *pOItem = (m_pOClientList->listView())->currentItem();
-	if (pOItem == NULL)
+	const QList<QTreeWidgetItem *> oitems
+		= (m_pOClientList->listView())->selectedItems();
+	const QList<QTreeWidgetItem *> iitems
+		= (m_pIClientList->listView())->selectedItems();
+
+	if (oitems.isEmpty() || iitems.isEmpty())
 		return false;
 
-	QTreeWidgetItem *pIItem = (m_pIClientList->listView())->currentItem();
-	if (pIItem == NULL)
-		return false;
+	QListIterator<QTreeWidgetItem *> oiter(oitems);
+	QListIterator<QTreeWidgetItem *> iiter(iitems);
 
-	if (pOItem->type() == QJACKCTL_CLIENTITEM) {
-		qjackctlClientItem *pOClient
-			= static_cast<qjackctlClientItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// Each-to-each connections...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (oport.hasNext() && iport.hasNext()) {
-				qjackctlPortItem *pOPort = oport.next();
-				qjackctlPortItem *pIPort = iport.next();
-				connectPortsEx(pOPort, pIPort);
+	const int iNumItems
+		= qMax(oitems.count(), iitems.count());
+
+	for (int i = 0; i < iNumItems; ++i) {
+		if (!oiter.hasNext())
+			oiter.toFront();
+		if (!iiter.hasNext())
+			iiter.toFront();
+		QTreeWidgetItem *pOItem = oiter.next();
+		QTreeWidgetItem *pIItem = iiter.next();
+		if (pOItem->type() == QJACKCTL_CLIENTITEM) {
+			qjackctlClientItem *pOClient
+				= static_cast<qjackctlClientItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// Each-to-each connections...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (oport.hasNext() && iport.hasNext()) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort = iport.next();
+					connectPortsEx(pOPort, pIPort);
+				}
+			} else {
+				// Many(all)-to-one/many connection...
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				while (oport.hasNext()
+					&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort
+						= static_cast<qjackctlPortItem *> (pIItem);
+					connectPortsEx(pOPort, pIPort);
+					pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
+				}
 			}
 		} else {
-			// Many(all)-to-one/many connection...
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			while (oport.hasNext()
-				&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
-				qjackctlPortItem *pOPort = oport.next();
+			qjackctlPortItem *pOPort
+				= static_cast<qjackctlPortItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// One-to-many(all) connection...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (iport.hasNext()) {
+					qjackctlPortItem *pIPort = iport.next();
+					connectPortsEx(pOPort, pIPort);
+				}
+			} else {
+				// One-to-one connection...
 				qjackctlPortItem *pIPort
 					= static_cast<qjackctlPortItem *> (pIItem);
 				connectPortsEx(pOPort, pIPort);
-				pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
 			}
 		}
-	} else {
-		qjackctlPortItem *pOPort
-			= static_cast<qjackctlPortItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// One-to-many(all) connection...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (iport.hasNext()) {
-				qjackctlPortItem *pIPort = iport.next();
-				connectPortsEx(pOPort, pIPort);
-			}
-		} else {
-			// One-to-one connection...
-			qjackctlPortItem *pIPort
-				= static_cast<qjackctlPortItem *> (pIItem);
-			connectPortsEx(pOPort, pIPort);
-		}
 	}
 
 	return true;
@@ -1723,61 +1721,75 @@ bool qjackctlConnect::canDisconnectSelected (void)
 
 bool qjackctlConnect::canDisconnectSelectedEx (void)
 {
-	QTreeWidgetItem *pOItem = (m_pOClientList->listView())->currentItem();
-	if (!pOItem)
+	const QList<QTreeWidgetItem *> oitems
+		= (m_pOClientList->listView())->selectedItems();
+	const QList<QTreeWidgetItem *> iitems
+		= (m_pIClientList->listView())->selectedItems();
+
+	if (oitems.isEmpty() || iitems.isEmpty())
 		return false;
 
-	QTreeWidgetItem *pIItem = (m_pIClientList->listView())->currentItem();
-	if (!pIItem)
-		return false;
+	QListIterator<QTreeWidgetItem *> oiter(oitems);
+	QListIterator<QTreeWidgetItem *> iiter(iitems);
 
-	if (pOItem->type() == QJACKCTL_CLIENTITEM) {
-		qjackctlClientItem *pOClient
-			= static_cast<qjackctlClientItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// Each-to-each connections...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (oport.hasNext() && iport.hasNext()) {
-				qjackctlPortItem *pOPort = oport.next();
-				qjackctlPortItem *pIPort = iport.next();
-				if (pOPort->findConnectPtr(pIPort) != NULL)
-					return true;
+	const int iNumItems
+		= qMax(oitems.count(), iitems.count());
+
+	for (int i = 0; i < iNumItems; ++i) {
+		if (!oiter.hasNext())
+			oiter.toFront();
+		if (!iiter.hasNext())
+			iiter.toFront();
+		QTreeWidgetItem *pOItem = oiter.next();
+		QTreeWidgetItem *pIItem = iiter.next();
+		if (pOItem->type() == QJACKCTL_CLIENTITEM) {
+			qjackctlClientItem *pOClient
+				= static_cast<qjackctlClientItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// Each-to-each connections...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (oport.hasNext() && iport.hasNext()) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort = iport.next();
+					if (pOPort->findConnectPtr(pIPort) != nullptr)
+						return true;
+				}
+			} else {
+				// Many(all)-to-one/many connection...
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				while (oport.hasNext()
+					&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort
+						= static_cast<qjackctlPortItem *> (pIItem);
+					if (pOPort->findConnectPtr(pIPort) != nullptr)
+						return true;
+					pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
+				}
 			}
 		} else {
-			// Many(all)-to-one/many connection...
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			while (oport.hasNext()
-				&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
-				qjackctlPortItem *pOPort = oport.next();
+			qjackctlPortItem *pOPort
+				= static_cast<qjackctlPortItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// One-to-many(all) connection...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (iport.hasNext()) {
+					qjackctlPortItem *pIPort = iport.next();
+					if (pOPort->findConnectPtr(pIPort) != nullptr)
+						return true;
+				}
+			} else {
+				// One-to-one connection...
 				qjackctlPortItem *pIPort
 					= static_cast<qjackctlPortItem *> (pIItem);
-				if (pOPort->findConnectPtr(pIPort) != NULL)
-					return true;
-				pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
+				return (pOPort->findConnectPtr(pIPort) != nullptr);
 			}
 		}
-	} else {
-		qjackctlPortItem *pOPort
-			= static_cast<qjackctlPortItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// One-to-many(all) connection...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (iport.hasNext()) {
-				qjackctlPortItem *pIPort = iport.next();
-				if (pOPort->findConnectPtr(pIPort) != NULL)
-					return true;
-			}
-		} else {
-			// One-to-one connection...
-			qjackctlPortItem *pIPort
-				= static_cast<qjackctlPortItem *> (pIItem);
-			return (pOPort->findConnectPtr(pIPort) != NULL);
-		}
 	}
 
 	return false;
@@ -1804,58 +1816,72 @@ bool qjackctlConnect::disconnectSelected (void)
 
 bool qjackctlConnect::disconnectSelectedEx (void)
 {
-	QTreeWidgetItem *pOItem = (m_pOClientList->listView())->currentItem();
-	if (pOItem == NULL)
+	const QList<QTreeWidgetItem *> oitems
+		= (m_pOClientList->listView())->selectedItems();
+	const QList<QTreeWidgetItem *> iitems
+		= (m_pIClientList->listView())->selectedItems();
+
+	if (oitems.isEmpty() || iitems.isEmpty())
 		return false;
 
-	QTreeWidgetItem *pIItem = (m_pIClientList->listView())->currentItem();
-	if (pIItem == NULL)
-		return false;
+	QListIterator<QTreeWidgetItem *> oiter(oitems);
+	QListIterator<QTreeWidgetItem *> iiter(iitems);
 
-	if (pOItem->type() == QJACKCTL_CLIENTITEM) {
-		qjackctlClientItem *pOClient
-			= static_cast<qjackctlClientItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// Each-to-each connections...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (oport.hasNext() && iport.hasNext()) {
-				qjackctlPortItem *pOPort = oport.next();
-				qjackctlPortItem *pIPort = iport.next();
-				disconnectPortsEx(pOPort, pIPort);
+	const int iNumItems
+		= qMax(oitems.count(), iitems.count());
+
+	for (int i = 0; i < iNumItems; ++i) {
+		if (!oiter.hasNext())
+			oiter.toFront();
+		if (!iiter.hasNext())
+			iiter.toFront();
+		QTreeWidgetItem *pOItem = oiter.next();
+		QTreeWidgetItem *pIItem = iiter.next();
+		if (pOItem->type() == QJACKCTL_CLIENTITEM) {
+			qjackctlClientItem *pOClient
+				= static_cast<qjackctlClientItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// Each-to-each connections...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (oport.hasNext() && iport.hasNext()) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort = iport.next();
+					disconnectPortsEx(pOPort, pIPort);
+				}
+			} else {
+				// Many(all)-to-one/many connection...
+				QListIterator<qjackctlPortItem *> oport(pOClient->ports());
+				while (oport.hasNext()
+					&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
+					qjackctlPortItem *pOPort = oport.next();
+					qjackctlPortItem *pIPort
+						= static_cast<qjackctlPortItem *> (pIItem);
+					disconnectPortsEx(pOPort, pIPort);
+					pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
+				}
 			}
 		} else {
-			// Many(all)-to-one/many connection...
-			QListIterator<qjackctlPortItem *> oport(pOClient->ports());
-			while (oport.hasNext()
-				&& pIItem && pIItem->type() == QJACKCTL_PORTITEM) {
-				qjackctlPortItem *pOPort = oport.next();
+			qjackctlPortItem *pOPort
+				= static_cast<qjackctlPortItem *> (pOItem);
+			if (pIItem->type() == QJACKCTL_CLIENTITEM) {
+				// One-to-many(all) connection...
+				qjackctlClientItem *pIClient
+					= static_cast<qjackctlClientItem *> (pIItem);
+				QListIterator<qjackctlPortItem *> iport(pIClient->ports());
+				while (iport.hasNext()) {
+					qjackctlPortItem *pIPort = iport.next();
+					disconnectPortsEx(pOPort, pIPort);
+				}
+			} else {
+				// One-to-one connection...
 				qjackctlPortItem *pIPort
 					= static_cast<qjackctlPortItem *> (pIItem);
 				disconnectPortsEx(pOPort, pIPort);
-				pIItem = (m_pIClientList->listView())->itemBelow(pIItem);
 			}
 		}
-	} else {
-		qjackctlPortItem *pOPort
-			= static_cast<qjackctlPortItem *> (pOItem);
-		if (pIItem->type() == QJACKCTL_CLIENTITEM) {
-			// One-to-many(all) connection...
-			qjackctlClientItem *pIClient
-				= static_cast<qjackctlClientItem *> (pIItem);
-			QListIterator<qjackctlPortItem *> iport(pIClient->ports());
-			while (iport.hasNext()) {
-				qjackctlPortItem *pIPort = iport.next();
-				disconnectPortsEx(pOPort, pIPort);
-			}
-		} else {
-			// One-to-one connection...
-			qjackctlPortItem *pIPort
-				= static_cast<qjackctlPortItem *> (pIItem);
-			disconnectPortsEx(pOPort, pIPort);
-		}
 	}
 
 	return true;
