@@ -1,7 +1,7 @@
 // qjackctlConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
 #ifndef __qjackctlConnect_h
 #define __qjackctlConnect_h
 
-#include "qjackctlConnectAlias.h"
+#include "qjackctlAliases.h"
 
 #include <QTreeWidget>
 #include <QSplitter>
@@ -238,7 +238,8 @@ public:
 	void refresh();
 
 	// Natural decimal sorting comparator.
-	static bool lessThan(const QTreeWidgetItem& i1, const QTreeWidgetItem& i2);
+	static bool lessThan(
+		const QTreeWidgetItem& item1, const QTreeWidgetItem& item2);
 
 private:
 
@@ -271,16 +272,15 @@ public:
 	int autoOpenTimeout() const;
 
 	// Aliasing support methods.
-	void setAliases(qjackctlConnectAlias *pAliases, bool bRenameEnabled);
-	qjackctlConnectAlias *aliases() const;
+	void setAliasList(qjackctlAliasList *pAliasList, bool bRenameEnabled);
+	qjackctlAliasList *aliasList() const;
 	bool isRenameEnabled() const;
 
 	// Binding indirect accessor.
 	qjackctlConnect *binding() const;
 
-	// Dirty flag accessors.
-	void setDirty (bool bDirty);
-	bool isDirty() const;
+	// Dirty aliases notification.
+	void emitAliasesChanged();
 
 protected slots:
 
@@ -327,7 +327,7 @@ private:
 	QPoint m_posDrag;
 
 	// Aliasing support.
-	qjackctlConnectAlias *m_pAliases;
+	qjackctlAliasList *m_pAliasList;
 	bool m_bRenameEnabled;
 };
 
@@ -403,22 +403,17 @@ public:
 	qjackctlClientList *OClientList() const;
 	qjackctlClientList *IClientList() const;
 
-	// Connector line style accessors.
-	void setBezierLines(bool bBezierLines);
-	bool isBezierLines() const;
-
 	// Common icon size pixmap accessors.
 	void setIconSize (int iIconSize);
 	int iconSize (void) const;
 
-	// Dirty flag accessors.
-	void setDirty (bool bDirty);
-	bool isDirty() const;
+	// Dirty aliases notification.
+	void emitAliasesChanged();
 
 signals:
 
 	// Contents change signal.
-	void contentsChanged();
+	void aliasesChanged();
 
 private:
 
@@ -430,9 +425,6 @@ private:
 	// The main binding object.
 	qjackctlConnect *m_pConnect;
 
-	// How we'll draw connector lines.
-	bool m_bBezierLines;
-
 	// How large will be those icons.
 	// 0 = 16x16 (default), 1 = 32x32, 2 = 64x64.
 	int m_iIconSize;
