@@ -1,7 +1,7 @@
 // qjackctlConnectionsForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -51,8 +51,6 @@ public:
 	qjackctlConnectView *midiConnectView() const;
 	qjackctlConnectView *alsaConnectView() const;
 
-	bool queryClose();
-
 	enum TabPage { AudioTab = 0, MidiTab = 1, AlsaTab = 2 };
 
 	void setTabPage(int iTabPage);
@@ -75,10 +73,7 @@ public:
 	void stabilizeMidi(bool bEnabled, bool bClear = false);
 	void stabilizeAlsa(bool bEnabled, bool bClear = false);
 
-	void setupAliases(qjackctlSetup *pSetup);
 	void updateAliases();
-	bool loadAliases();
-	bool saveAliases();
 
 public slots:
 
@@ -86,7 +81,7 @@ public slots:
 	void audioDisconnectSelected();
 	void audioDisconnectAll();
 	void audioExpandAll();
-	void audioRefreshClear();
+	void audioAliasesChanged();
 	void audioRefresh();
 	void audioStabilize();
 
@@ -94,7 +89,7 @@ public slots:
 	void midiDisconnectSelected();
 	void midiDisconnectAll();
 	void midiExpandAll();
-	void midiRefreshClear();
+	void midiAliasesChanged();
 	void midiRefresh();
 	void midiStabilize();
 
@@ -102,7 +97,7 @@ public slots:
 	void alsaDisconnectSelected();
 	void alsaDisconnectAll();
 	void alsaExpandAll();
-	void alsaRefreshClear();
+	void alsaAliasesChanged();
 	void alsaRefresh();
 	void alsaStabilize();
 
@@ -129,8 +124,8 @@ private:
 	qjackctlJackConnect *m_pAudioConnect;
 	qjackctlJackConnect *m_pMidiConnect;
 	qjackctlAlsaConnect *m_pAlsaConnect;
+
 	qjackctlSetup       *m_pSetup;
-	QString              m_sPreset;
 };
 
 
