@@ -783,7 +783,7 @@ void qjackctlGraphForm::showEvent ( QShowEvent *pShowEvent )
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->stabilizeForm();
+		pMainForm->stabilizeFormEx();
 
 	QWidget::showEvent(pShowEvent);
 }
@@ -796,7 +796,7 @@ void qjackctlGraphForm::hideEvent ( QHideEvent *pHideEvent )
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->stabilizeForm();
+		pMainForm->stabilizeFormEx();
 }
 
 
@@ -820,7 +820,6 @@ void qjackctlGraphForm::closeEvent ( QCloseEvent *pCloseEvent )
 }
 
 
-
 // Special port-type color methods.
 void qjackctlGraphForm::updateViewColorsAction ( QAction *action  )
 {
