@@ -1,7 +1,7 @@
 // qjackctlMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,9 +27,9 @@
 #include "qjackctlSetup.h"
 
 #include <QProcess>
-#include <QDateTime>
+#include <QTime>
 #include <QMenu>
-
+#include <QElapsedTimer>
 #include <QSessionManager>
 
 #include <jack/jack.h>
@@ -199,6 +199,8 @@ protected:
 	bool queryClose();
 	bool queryClosePreset();
 
+	void showEvent(QShowEvent *pShowEvent);
+	void hideEvent(QHideEvent *pHideEvent);
 	void closeEvent(QCloseEvent *pCloseEvent);
 	void customEvent(QEvent *pEvent);
 
@@ -224,7 +226,8 @@ protected:
 	void updateXrunCount();
 
 	QString formatTime(float secs) const;
-	QString formatElapsedTime(int iStatusItem, const QTime& t, bool bElapsed) const;
+	QString formatElapsedTime(int iStatusItem,
+		const QTime& time, const QElapsedTimer& timer) const;
 	void updateElapsedTimes();
 
 	void updateContextMenu();
@@ -348,8 +351,12 @@ private:
 	float m_fXrunMax;
 	float m_fXrunMin;
 	float m_fXrunLast;
-	QTime m_tXrunLast;
-	QTime m_tResetLast;
+
+	QTime m_timeXrunLast;
+	QTime m_timeResetLast;
+
+	QElapsedTimer m_timerXrunLast;
+	QElapsedTimer m_timerResetLast;
 
 	qjackctlMessagesStatusForm *m_pMessagesStatusForm;
 	qjackctlSessionForm     *m_pSessionForm;
