@@ -39,6 +39,8 @@
 
 #if defined(__WIN32__) || defined(_WIN32) || defined(WIN32)
 #define DEFAULT_DRIVER "portaudio"
+#elif defined(__APPLE__)
+#define DEFAULT_DRIVER "coreaudio"
 #else
 #define DEFAULT_DRIVER "alsa"
 #endif
@@ -113,6 +115,8 @@ void qjackctlSetup::loadSetup (void)
 	sDisplayFont2            = m_settings.value("/DisplayFont2").toString();
 	bDisplayEffect           = m_settings.value("/DisplayEffect", true).toBool();
 	bDisplayBlink            = m_settings.value("/DisplayBlink", true).toBool();
+	sCustomColorTheme        = m_settings.value("/CustomColorTheme").toString();
+	sCustomStyleTheme        = m_settings.value("/CustomStyleTheme").toString();
 	iJackClientPortAlias     = m_settings.value("/JackClientPortAlias", 0).toInt();
 	bJackClientPortMetadata  = m_settings.value("/JackClientPortMetadata", false).toBool();
 	iConnectionsIconSize     = m_settings.value("/ConnectionsIconSize", QJACKCTL_ICON_16X16).toInt();
@@ -225,6 +229,8 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/DisplayFont2",            sDisplayFont2);
 	m_settings.setValue("/DisplayEffect",           bDisplayEffect);
 	m_settings.setValue("/DisplayBlink",            bDisplayBlink);
+	m_settings.setValue("/CustomColorTheme",        sCustomColorTheme);
+	m_settings.setValue("/CustomStyleTheme",        sCustomStyleTheme);
 	m_settings.setValue("/JackClientPortAlias",     iJackClientPortAlias);
 	m_settings.setValue("/JackClientPortMetadata",  bJackClientPortMetadata);
 	m_settings.setValue("/ConnectionsIconSize",     iConnectionsIconSize);
@@ -586,13 +592,13 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 		else if (sArg == "-v" || sArg == "--version") {
 			out << QString("Qt: %1\n")
 				.arg(qVersion());
-			out << QString("%1: %2\n")
-				.arg(QJACKCTL_TITLE)
-				.arg(CONFIG_BUILD_VERSION);
 		#ifdef CONFIG_JACK_VERSION
 			out << QString("JACK: %1\n")
 				.arg(jack_get_version_string());
 		#endif
+			out << QString("%1: %2\n")
+				.arg(QJACKCTL_TITLE)
+				.arg(CONFIG_BUILD_VERSION);
 			return false;
 		}	// FIXME: Avoid auto-start jackd stuffed args!
 		else if (sArg != "-T" && sArg != "-ndefault") {
