@@ -78,6 +78,8 @@ protected slots:
 	void chooseMessagesFont();
 	void chooseConnectionsFont();
 
+	void editCustomColorThemes();
+
 	void buffSizeChanged();
 
 	void settingsChanged();
@@ -111,11 +113,14 @@ protected:
 
 	void symbolMenu(QLineEdit * pLineEdit, QToolButton * pToolButton );
 
+	// Custom color/style themes settlers.
+	void resetCustomColorThemes(const QString& sCustomColorTheme);
+	void resetCustomStyleThemes(const QString& sCustomStyleTheme);
+
 	void stabilizeForm();
 
 	void showEvent(QShowEvent *);
 	void hideEvent(QHideEvent *);
-	void closeEvent(QCloseEvent *);
 
 private:
 
