@@ -1,7 +1,7 @@
 // qjackctlSocketForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@
 #include "qjackctlMainForm.h"
 
 #include "qjackctlPatchbay.h"
-#include "qjackctlConnectAlias.h"
+#include "qjackctlAliases.h"
 
 #include <QMessageBox>
 #include <QButtonGroup>
@@ -46,10 +46,10 @@ qjackctlSocketForm::qjackctlSocketForm (
 	// Setup UI struct...
 	m_ui.setupUi(this);
 
-	m_pSocketList  = NULL;
+	m_pSocketList  = nullptr;
 	m_bSocketNew   = false;
 	m_iSocketNameChanged = 0;
-	m_ppPixmaps    = NULL;
+	m_ppPixmaps    = nullptr;
 	m_iDirtyCount  = 0;
 
 	// Setup time-display radio-button group.
@@ -66,7 +66,7 @@ qjackctlSocketForm::qjackctlSocketForm (
 	QHeaderView *pHeader = m_ui.PlugListView->header();
 //	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(300);
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 //	pHeader->setSectionResizeMode(QHeaderView::Custom);
 	pHeader->setSectionsMovable(false);
 #else
@@ -227,7 +227,7 @@ void qjackctlSocketForm::load ( qjackctlPatchbaySocket *pSocket )
 	m_ui.ExclusiveCheckBox->setChecked(pSocket->isExclusive());
 
 	m_ui.PlugListView->clear();
-	QTreeWidgetItem *pPlugItem = NULL;
+	QTreeWidgetItem *pPlugItem = nullptr;
 	QStringListIterator iter(pSocket->pluglist());
 	while (iter.hasNext()) {
 		const QString& sPlugName = iter.next();
@@ -275,7 +275,7 @@ void qjackctlSocketForm::save ( qjackctlPatchbaySocket *pSocket )
 	if (m_ui.SocketForwardComboBox->currentIndex() > 0)
 		pSocket->setForward(m_ui.SocketForwardComboBox->currentText());
 	else
-		pSocket->setForward(QString::null);
+		pSocket->setForward(QString());
 
 	m_iDirtyCount = 0;
 }
@@ -326,7 +326,7 @@ bool qjackctlSocketForm::validateForm (void)
 // Validate form fields and accept it valid.
 void qjackctlSocketForm::accept (void)
 {
-	if (m_pSocketList == NULL)
+	if (m_pSocketList == nullptr)
 		return;
 
 	if (!validateForm())
@@ -392,7 +392,7 @@ void qjackctlSocketForm::changed (void)
 // Add new Plug to socket list.
 void qjackctlSocketForm::addPlug (void)
 {
-	if (m_ppPixmaps == NULL)
+	if (m_ppPixmaps == nullptr)
 		return;
 
 	QString sPlugName = m_ui.PlugNameComboBox->currentText();
@@ -404,7 +404,7 @@ void qjackctlSocketForm::addPlug (void)
 		if (pItem) {
 			pItem->setText(0, sPlugName);
 			pItem->setFlags(pItem->flags() | Qt::ItemIsEditable);
-			QPixmap *pXpmPlug = NULL;
+			QPixmap *pXpmPlug = nullptr;
 			switch (m_pSocketTypeButtonGroup->checkedId()) {
 			case 0: // QJACKCTL_SOCKETTYPE_JACK_AUDIO
 				pXpmPlug = m_ppPixmaps[QJACKCTL_XPM_AUDIO_PLUG];
@@ -419,7 +419,7 @@ void qjackctlSocketForm::addPlug (void)
 			pItem->setSelected(true);
 			m_ui.PlugListView->setCurrentItem(pItem);
 		}
-		m_ui.PlugNameComboBox->setEditText(QString::null);
+		m_ui.PlugNameComboBox->setEditText(QString());
 	}
 
 	clientNameChanged();
@@ -514,7 +514,7 @@ void qjackctlSocketForm::customContextMenu ( const QPoint& pos )
 	int iItem = 0;
 	int iItemCount = 0;
 	QTreeWidgetItem *pItem = m_ui.PlugListView->itemAt(pos);
-	if (pItem == NULL)
+	if (pItem == nullptr)
 		pItem = m_ui.PlugListView->currentItem();
 	if (pItem) {
 		iItem = m_ui.PlugListView->indexOfTopLevelItem(pItem);
@@ -538,7 +538,7 @@ void qjackctlSocketForm::customContextMenu ( const QPoint& pos )
 		SLOT(activateAddPlugMenu(QAction*)));
 	pAddPlugMenu->setEnabled(iIndex > 0);
 	// Build the plug context menu...
-	const bool bEnabled = (pItem != NULL);
+	const bool bEnabled = (pItem != nullptr);
 	pAction = menu.addAction(QIcon(":/images/edit1.png"),
 		tr("Edit"), this, SLOT(editPlug()));
 	pAction->setEnabled(bEnabled);
@@ -560,11 +560,11 @@ void qjackctlSocketForm::customContextMenu ( const QPoint& pos )
 void qjackctlSocketForm::updateJackClients ( int iSocketType )
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return;
 
 	const char *pszJackPortType = JACK_DEFAULT_AUDIO_TYPE;
@@ -581,7 +581,7 @@ void qjackctlSocketForm::updateJackClients ( int iSocketType )
 
 	// Grab all client ports.
 	const char **ppszClientPorts = jack_get_ports(
-		pJackClient, NULL, pszJackPortType,
+		pJackClient, nullptr, pszJackPortType,
 		(bReadable ? JackPortIsOutput : JackPortIsInput));
 	if (ppszClientPorts) {
 		int iClientPort = 0;
@@ -590,7 +590,7 @@ void qjackctlSocketForm::updateJackClients ( int iSocketType )
 			int iColon = sClientPort.indexOf(':');
 			if (iColon >= 0) {
 				QString sClientName
-					= qjackctlClientAlias::escapeRegExpDigits(
+					= qjackctlAliasItem::escapeRegExpDigits(
 						sClientPort.left(iColon));
 				bool bExists = false;
 				for (int i = 0;
@@ -616,11 +616,11 @@ void qjackctlSocketForm::updateAlsaClients ( int iSocketType )
 #ifdef CONFIG_ALSA_SEQ
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
-	if (pAlsaSeq == NULL)
+	if (pAlsaSeq == nullptr)
 		return;
 
 	const bool bReadable = m_pSocketList->isReadable();
@@ -641,7 +641,7 @@ void qjackctlSocketForm::updateAlsaClients ( int iSocketType )
 	while (snd_seq_query_next_client(pAlsaSeq, pClientInfo) >= 0) {
 		const int iAlsaClient = snd_seq_client_info_get_client(pClientInfo);
 		QString sClient
-			= qjackctlClientAlias::escapeRegExpDigits(
+			= qjackctlAliasItem::escapeRegExpDigits(
 				QString::fromUtf8(snd_seq_client_info_get_name(pClientInfo)));
 		if (iAlsaClient > 0) {
 			bool bExists = false;
@@ -672,9 +672,9 @@ void qjackctlSocketForm::updateAlsaClients ( int iSocketType )
 // Socket type change slot.
 void qjackctlSocketForm::socketTypeChanged (void)
 {
-	if (m_ppPixmaps == NULL)
+	if (m_ppPixmaps == nullptr)
 		return;
-	if (m_pSocketList == NULL)
+	if (m_pSocketList == nullptr)
 		return;
 
 	const bool bBlockSignals = m_ui.ClientNameComboBox->blockSignals(true);
@@ -682,8 +682,8 @@ void qjackctlSocketForm::socketTypeChanged (void)
 
 	m_ui.ClientNameComboBox->clear();
 
-	QPixmap *pXpmSocket = NULL;
-	QPixmap *pXpmPlug   = NULL;
+	QPixmap *pXpmSocket = nullptr;
+	QPixmap *pXpmPlug   = nullptr;
 
 	const bool bReadable = m_pSocketList->isReadable();
 	const int iSocketType = m_pSocketTypeButtonGroup->checkedId();
@@ -781,11 +781,11 @@ void qjackctlSocketForm::socketNameChanged (void)
 void qjackctlSocketForm::updateJackPlugs ( int iSocketType )
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	jack_client_t *pJackClient = pMainForm->jackClient();
-	if (pJackClient == NULL)
+	if (pJackClient == nullptr)
 		return;
 
 	const char *pszJackPortType = JACK_DEFAULT_AUDIO_TYPE;
@@ -805,7 +805,7 @@ void qjackctlSocketForm::updateJackPlugs ( int iSocketType )
 	const bool bReadable = m_pSocketList->isReadable();
 	const QIcon icon(*m_ppPixmaps[iPixmap]);
 	const char **ppszClientPorts = jack_get_ports(
-		pJackClient, NULL, pszJackPortType,
+		pJackClient, nullptr, pszJackPortType,
 		(bReadable ? JackPortIsOutput : JackPortIsInput));
 	if (ppszClientPorts) {
 		int iClientPort = 0;
@@ -814,7 +814,7 @@ void qjackctlSocketForm::updateJackPlugs ( int iSocketType )
 			const int iColon = sClientPort.indexOf(':');
 			if (iColon >= 0 && rxClientName.exactMatch(sClientPort.left(iColon))) {
 				QString sPort
-					= qjackctlClientAlias::escapeRegExpDigits(
+					= qjackctlAliasItem::escapeRegExpDigits(
 						sClientPort.right(sClientPort.length() - iColon - 1));
 				if (m_ui.PlugListView->findItems(sPort, Qt::MatchExactly).isEmpty())
 					m_ui.PlugNameComboBox->addItem(icon, sPort);
@@ -835,11 +835,11 @@ void qjackctlSocketForm::updateAlsaPlugs ( int iSocketType )
 #ifdef CONFIG_ALSA_SEQ
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm == NULL)
+	if (pMainForm == nullptr)
 		return;
 
 	snd_seq_t *pAlsaSeq = pMainForm->alsaSeq();
-	if (pAlsaSeq == NULL)
+	if (pAlsaSeq == nullptr)
 		return;
 
 	const QString sClientName = m_ui.ClientNameComboBox->currentText();
@@ -875,7 +875,7 @@ void qjackctlSocketForm::updateAlsaPlugs ( int iSocketType )
 				if (((uiPortCapability & uiAlsaFlags) == uiAlsaFlags) &&
 					((uiPortCapability & SND_SEQ_PORT_CAP_NO_EXPORT) == 0)) {
 					QString sPort
-						= qjackctlClientAlias::escapeRegExpDigits(
+						= qjackctlAliasItem::escapeRegExpDigits(
 							QString::fromUtf8(snd_seq_port_info_get_name(pPortInfo)));
 					if (m_ui.PlugListView->findItems(sPort, Qt::MatchExactly).isEmpty())
 						m_ui.PlugNameComboBox->addItem(icon, sPort);
@@ -891,9 +891,9 @@ void qjackctlSocketForm::updateAlsaPlugs ( int iSocketType )
 // Update client list if available.
 void qjackctlSocketForm::clientNameChanged (void)
 {
-	if (m_ppPixmaps == NULL)
+	if (m_ppPixmaps == nullptr)
 		return;
-	if (m_pSocketList == NULL)
+	if (m_pSocketList == nullptr)
 		return;
 
 	m_ui.PlugNameComboBox->clear();
